# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/control_cmd.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.canbus.proto import chassis_pb2 as modules_dot_canbus_dot_proto_dot_chassis__pb2
from modules.common.proto import drive_state_pb2 as modules_dot_common_dot_proto_dot_drive__state__pb2
from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2
from modules.common.proto import vehicle_signal_pb2 as modules_dot_common_dot_proto_dot_vehicle__signal__pb2
from modules.control.proto import input_debug_pb2 as modules_dot_control_dot_proto_dot_input__debug__pb2
from modules.control.proto import pad_msg_pb2 as modules_dot_control_dot_proto_dot_pad__msg__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/control_cmd.proto',
  package='apollo.control',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'modules/control/proto/control_cmd.proto\x12\x0e\x61pollo.control\x1a\"modules/canbus/proto/chassis.proto\x1a&modules/common/proto/drive_state.proto\x1a!modules/common/proto/header.proto\x1a$modules/common/proto/pnc_point.proto\x1a)modules/common/proto/vehicle_signal.proto\x1a\'modules/control/proto/input_debug.proto\x1a#modules/control/proto/pad_msg.proto\"^\n\x0cLatencyStats\x12\x15\n\rtotal_time_ms\x18\x01 \x01(\x01\x12\x1a\n\x12\x63ontroller_time_ms\x18\x02 \x03(\x01\x12\x1b\n\x13total_time_exceeded\x18\x03 \x01(\x08\"\xb7\x06\n\x0e\x43ontrolCommand\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x10\n\x08throttle\x18\x03 \x01(\x01\x12\r\n\x05\x62rake\x18\x04 \x01(\x01\x12\x15\n\rsteering_rate\x18\x06 \x01(\x01\x12\x17\n\x0fsteering_target\x18\x07 \x01(\x01\x12\x15\n\rparking_brake\x18\x08 \x01(\x08\x12\r\n\x05speed\x18\t \x01(\x01\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\n \x01(\x01\x12\x17\n\x0breset_model\x18\x10 \x01(\x08\x42\x02\x18\x01\x12\x15\n\rengine_on_off\x18\x11 \x01(\x08\x12\x1b\n\x13trajectory_fraction\x18\x12 \x01(\x01\x12<\n\x0c\x64riving_mode\x18\x13 \x01(\x0e\x32\".apollo.canbus.Chassis.DrivingModeB\x02\x18\x01\x12:\n\rgear_location\x18\x14 \x01(\x0e\x32#.apollo.canbus.Chassis.GearPosition\x12$\n\x05\x64\x65\x62ug\x18\x16 \x01(\x0b\x32\x15.apollo.control.Debug\x12,\n\x06signal\x18\x17 \x01(\x0b\x32\x1c.apollo.common.VehicleSignal\x12\x33\n\rlatency_stats\x18\x18 \x01(\x0b\x32\x1c.apollo.control.LatencyStats\x12+\n\x07pad_msg\x18\x19 \x01(\x0b\x32\x1a.apollo.control.PadMessage\x12\x32\n\rengage_advice\x18\x1a \x01(\x0b\x32\x1b.apollo.common.EngageAdvice\x12\x1e\n\x0fis_in_safe_mode\x18\x1b \x01(\x08:\x05\x66\x61lse\x12\x15\n\tleft_turn\x18\r \x01(\x08\x42\x02\x18\x01\x12\x16\n\nright_turn\x18\x0e \x01(\x08\x42\x02\x18\x01\x12\x15\n\thigh_beam\x18\x0b \x01(\x08\x42\x02\x18\x01\x12\x14\n\x08low_beam\x18\x0c \x01(\x08\x42\x02\x18\x01\x12\x10\n\x04horn\x18\x0f \x01(\x08\x42\x02\x18\x01\x12\x32\n\nturnsignal\x18\x15 \x01(\x0e\x32\x1a.apollo.control.TurnSignalB\x02\x18\x01\"\xad\x08\n\x17SimpleLongitudinalDebug\x12\x19\n\x11station_reference\x18\x01 \x01(\x01\x12\x15\n\rstation_error\x18\x02 \x01(\x01\x12\x1d\n\x15station_error_limited\x18\x03 \x01(\x01\x12\x1d\n\x15preview_station_error\x18\x04 \x01(\x01\x12\x17\n\x0fspeed_reference\x18\x05 \x01(\x01\x12\x13\n\x0bspeed_error\x18\x06 \x01(\x01\x12&\n\x1espeed_controller_input_limited\x18\x07 \x01(\x01\x12\x1f\n\x17preview_speed_reference\x18\x08 \x01(\x01\x12\x1b\n\x13preview_speed_error\x18\t \x01(\x01\x12&\n\x1epreview_acceleration_reference\x18\n \x01(\x01\x12\"\n\x1a\x61\x63\x63\x65leration_cmd_closeloop\x18\x0b \x01(\x01\x12\x18\n\x10\x61\x63\x63\x65leration_cmd\x18\x0c \x01(\x01\x12\x1b\n\x13\x61\x63\x63\x65leration_lookup\x18\r \x01(\x01\x12\x14\n\x0cspeed_lookup\x18\x0e \x01(\x01\x12\x19\n\x11\x63\x61libration_value\x18\x0f \x01(\x01\x12\x14\n\x0cthrottle_cmd\x18\x10 \x01(\x01\x12\x11\n\tbrake_cmd\x18\x11 \x01(\x01\x12\x14\n\x0cis_full_stop\x18\x12 \x01(\x08\x12!\n\x19slope_offset_compensation\x18\x13 \x01(\x01\x12\x17\n\x0f\x63urrent_station\x18\x14 \x01(\x01\x12\x13\n\x0bpath_remain\x18\x15 \x01(\x01\x12\x1d\n\x15pid_saturation_status\x18\x16 \x01(\x05\x12!\n\x19leadlag_saturation_status\x18\x17 \x01(\x05\x12\x14\n\x0cspeed_offset\x18\x18 \x01(\x01\x12\x15\n\rcurrent_speed\x18\x19 \x01(\x01\x12\x1e\n\x16\x61\x63\x63\x65leration_reference\x18\x1a \x01(\x01\x12\x1c\n\x14\x63urrent_acceleration\x18\x1b \x01(\x01\x12\x1a\n\x12\x61\x63\x63\x65leration_error\x18\x1c \x01(\x01\x12\x16\n\x0ejerk_reference\x18\x1d \x01(\x01\x12\x14\n\x0c\x63urrent_jerk\x18\x1e \x01(\x01\x12\x12\n\njerk_error\x18\x1f \x01(\x01\x12=\n\x15\x63urrent_matched_point\x18  \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12?\n\x17\x63urrent_reference_point\x18! \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12?\n\x17preview_reference_point\x18\" \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\"\x93\x08\n\x12SimpleLateralDebug\x12\x15\n\rlateral_error\x18\x01 \x01(\x01\x12\x13\n\x0bref_heading\x18\x02 \x01(\x01\x12\x0f\n\x07heading\x18\x03 \x01(\x01\x12\x15\n\rheading_error\x18\x04 \x01(\x01\x12\x1a\n\x12heading_error_rate\x18\x05 \x01(\x01\x12\x1a\n\x12lateral_error_rate\x18\x06 \x01(\x01\x12\x11\n\tcurvature\x18\x07 \x01(\x01\x12\x13\n\x0bsteer_angle\x18\x08 \x01(\x01\x12\x1f\n\x17steer_angle_feedforward\x18\t \x01(\x01\x12(\n steer_angle_lateral_contribution\x18\n \x01(\x01\x12-\n%steer_angle_lateral_rate_contribution\x18\x0b \x01(\x01\x12(\n steer_angle_heading_contribution\x18\x0c \x01(\x01\x12-\n%steer_angle_heading_rate_contribution\x18\r \x01(\x01\x12\x1c\n\x14steer_angle_feedback\x18\x0e \x01(\x01\x12\x19\n\x11steering_position\x18\x0f \x01(\x01\x12\x11\n\tref_speed\x18\x10 \x01(\x01\x12\x1b\n\x13steer_angle_limited\x18\x11 \x01(\x01\x12\x1c\n\x14lateral_acceleration\x18\x12 \x01(\x01\x12\x14\n\x0clateral_jerk\x18\x13 \x01(\x01\x12\x18\n\x10ref_heading_rate\x18\x14 \x01(\x01\x12\x14\n\x0cheading_rate\x18\x15 \x01(\x01\x12 \n\x18ref_heading_acceleration\x18\x16 \x01(\x01\x12\x1c\n\x14heading_acceleration\x18\x17 \x01(\x01\x12\"\n\x1aheading_error_acceleration\x18\x18 \x01(\x01\x12\x18\n\x10ref_heading_jerk\x18\x19 \x01(\x01\x12\x14\n\x0cheading_jerk\x18\x1a \x01(\x01\x12\x1a\n\x12heading_error_jerk\x18\x1b \x01(\x01\x12\x1e\n\x16lateral_error_feedback\x18\x1c \x01(\x01\x12\x1e\n\x16heading_error_feedback\x18\x1d \x01(\x01\x12<\n\x14\x63urrent_target_point\x18\x1e \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12$\n\x1csteer_angle_feedback_augment\x18\x1f \x01(\x01\x12\x33\n\x10steer_mrac_debug\x18  \x01(\x0b\x32\x19.apollo.control.MracDebug\x12 \n\x18steer_mrac_enable_status\x18! \x01(\x08\"\xf2\n\n\x0eSimpleMPCDebug\x12\x15\n\rlateral_error\x18\x01 \x01(\x01\x12\x13\n\x0bref_heading\x18\x02 \x01(\x01\x12\x0f\n\x07heading\x18\x03 \x01(\x01\x12\x15\n\rheading_error\x18\x04 \x01(\x01\x12\x1a\n\x12heading_error_rate\x18\x05 \x01(\x01\x12\x1a\n\x12lateral_error_rate\x18\x06 \x01(\x01\x12\x11\n\tcurvature\x18\x07 \x01(\x01\x12\x13\n\x0bsteer_angle\x18\x08 \x01(\x01\x12\x1f\n\x17steer_angle_feedforward\x18\t \x01(\x01\x12(\n steer_angle_lateral_contribution\x18\n \x01(\x01\x12-\n%steer_angle_lateral_rate_contribution\x18\x0b \x01(\x01\x12(\n steer_angle_heading_contribution\x18\x0c \x01(\x01\x12-\n%steer_angle_heading_rate_contribution\x18\r \x01(\x01\x12\x1c\n\x14steer_angle_feedback\x18\x0e \x01(\x01\x12\x19\n\x11steering_position\x18\x0f \x01(\x01\x12\x11\n\tref_speed\x18\x10 \x01(\x01\x12\x1b\n\x13steer_angle_limited\x18\x11 \x01(\x01\x12\x19\n\x11station_reference\x18\x12 \x01(\x01\x12\x15\n\rstation_error\x18\x13 \x01(\x01\x12\x17\n\x0fspeed_reference\x18\x14 \x01(\x01\x12\x13\n\x0bspeed_error\x18\x15 \x01(\x01\x12\x1e\n\x16\x61\x63\x63\x65leration_reference\x18\x16 \x01(\x01\x12\x14\n\x0cis_full_stop\x18\x17 \x01(\x08\x12\x18\n\x10station_feedback\x18\x18 \x01(\x01\x12\x16\n\x0espeed_feedback\x18\x19 \x01(\x01\x12\"\n\x1a\x61\x63\x63\x65leration_cmd_closeloop\x18\x1a \x01(\x01\x12\x18\n\x10\x61\x63\x63\x65leration_cmd\x18\x1b \x01(\x01\x12\x1b\n\x13\x61\x63\x63\x65leration_lookup\x18\x1c \x01(\x01\x12\x14\n\x0cspeed_lookup\x18\x1d \x01(\x01\x12\x19\n\x11\x63\x61libration_value\x18\x1e \x01(\x01\x12(\n steer_unconstrained_control_diff\x18\x1f \x01(\x01\x12,\n$steer_angle_feedforward_compensation\x18  \x01(\x01\x12\x18\n\x10matrix_q_updated\x18! \x03(\x01\x12\x18\n\x10matrix_r_updated\x18\" \x03(\x01\x12\x1c\n\x14lateral_acceleration\x18# \x01(\x01\x12\x14\n\x0clateral_jerk\x18$ \x01(\x01\x12\x18\n\x10ref_heading_rate\x18% \x01(\x01\x12\x14\n\x0cheading_rate\x18& \x01(\x01\x12 \n\x18ref_heading_acceleration\x18\' \x01(\x01\x12\x1c\n\x14heading_acceleration\x18( \x01(\x01\x12\"\n\x1aheading_error_acceleration\x18) \x01(\x01\x12\x18\n\x10ref_heading_jerk\x18* \x01(\x01\x12\x14\n\x0cheading_jerk\x18+ \x01(\x01\x12\x1a\n\x12heading_error_jerk\x18, \x01(\x01\x12\x1d\n\x15\x61\x63\x63\x65leration_feedback\x18- \x01(\x01\x12\x1a\n\x12\x61\x63\x63\x65leration_error\x18. \x01(\x01\x12\x16\n\x0ejerk_reference\x18/ \x01(\x01\x12\x15\n\rjerk_feedback\x18\x30 \x01(\x01\x12\x12\n\njerk_error\x18\x31 \x01(\x01\"\xed\x01\n\tMracDebug\x12\x18\n\x10mrac_model_order\x18\x01 \x01(\x05\x12\x1c\n\x14mrac_reference_state\x18\x02 \x03(\x01\x12\x18\n\x10mrac_state_error\x18\x03 \x03(\x01\x12<\n\x12mrac_adaptive_gain\x18\x04 \x01(\x0b\x32 .apollo.control.MracAdaptiveGain\x12(\n mrac_reference_saturation_status\x18\x05 \x01(\x05\x12&\n\x1emrac_control_saturation_status\x18\x06 \x01(\x05\"m\n\x10MracAdaptiveGain\x12\x1b\n\x13state_adaptive_gain\x18\x01 \x03(\x01\x12\x1b\n\x13input_adaptive_gain\x18\x02 \x03(\x01\x12\x1f\n\x17nonlinear_adaptive_gain\x18\x03 \x03(\x01\"\xf3\x01\n\x05\x44\x65\x62ug\x12\x41\n\x10simple_lon_debug\x18\x01 \x01(\x0b\x32\'.apollo.control.SimpleLongitudinalDebug\x12<\n\x10simple_lat_debug\x18\x02 \x01(\x0b\x32\".apollo.control.SimpleLateralDebug\x12/\n\x0binput_debug\x18\x03 \x01(\x0b\x32\x1a.apollo.control.InputDebug\x12\x38\n\x10simple_mpc_debug\x18\x04 \x01(\x0b\x32\x1e.apollo.control.SimpleMPCDebug*:\n\nTurnSignal\x12\r\n\tTURN_NONE\x10\x00\x12\r\n\tTURN_LEFT\x10\x01\x12\x0e\n\nTURN_RIGHT\x10\x02'
  ,
  dependencies=[modules_dot_canbus_dot_proto_dot_chassis__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_drive__state__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_vehicle__signal__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_input__debug__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_pad__msg__pb2.DESCRIPTOR,])

_TURNSIGNAL = _descriptor.EnumDescriptor(
  name='TurnSignal',
  full_name='apollo.control.TurnSignal',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TURN_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5363,
  serialized_end=5421,
)
_sym_db.RegisterEnumDescriptor(_TURNSIGNAL)

TurnSignal = enum_type_wrapper.EnumTypeWrapper(_TURNSIGNAL)
TURN_NONE = 0
TURN_LEFT = 1
TURN_RIGHT = 2



_LATENCYSTATS = _descriptor.Descriptor(
  name='LatencyStats',
  full_name='apollo.control.LatencyStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_time_ms', full_name='apollo.control.LatencyStats.total_time_ms', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_time_ms', full_name='apollo.control.LatencyStats.controller_time_ms', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_time_exceeded', full_name='apollo.control.LatencyStats.total_time_exceeded', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=423,
)


_CONTROLCOMMAND = _descriptor.Descriptor(
  name='ControlCommand',
  full_name='apollo.control.ControlCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.control.ControlCommand.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle', full_name='apollo.control.ControlCommand.throttle', index=1,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake', full_name='apollo.control.ControlCommand.brake', index=2,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_rate', full_name='apollo.control.ControlCommand.steering_rate', index=3,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_target', full_name='apollo.control.ControlCommand.steering_target', index=4,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_brake', full_name='apollo.control.ControlCommand.parking_brake', index=5,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.control.ControlCommand.speed', index=6,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='apollo.control.ControlCommand.acceleration', index=7,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reset_model', full_name='apollo.control.ControlCommand.reset_model', index=8,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engine_on_off', full_name='apollo.control.ControlCommand.engine_on_off', index=9,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_fraction', full_name='apollo.control.ControlCommand.trajectory_fraction', index=10,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driving_mode', full_name='apollo.control.ControlCommand.driving_mode', index=11,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_location', full_name='apollo.control.ControlCommand.gear_location', index=12,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug', full_name='apollo.control.ControlCommand.debug', index=13,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal', full_name='apollo.control.ControlCommand.signal', index=14,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency_stats', full_name='apollo.control.ControlCommand.latency_stats', index=15,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pad_msg', full_name='apollo.control.ControlCommand.pad_msg', index=16,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engage_advice', full_name='apollo.control.ControlCommand.engage_advice', index=17,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_in_safe_mode', full_name='apollo.control.ControlCommand.is_in_safe_mode', index=18,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_turn', full_name='apollo.control.ControlCommand.left_turn', index=19,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_turn', full_name='apollo.control.ControlCommand.right_turn', index=20,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high_beam', full_name='apollo.control.ControlCommand.high_beam', index=21,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low_beam', full_name='apollo.control.ControlCommand.low_beam', index=22,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='horn', full_name='apollo.control.ControlCommand.horn', index=23,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turnsignal', full_name='apollo.control.ControlCommand.turnsignal', index=24,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=1249,
)


_SIMPLELONGITUDINALDEBUG = _descriptor.Descriptor(
  name='SimpleLongitudinalDebug',
  full_name='apollo.control.SimpleLongitudinalDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='station_reference', full_name='apollo.control.SimpleLongitudinalDebug.station_reference', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_error', full_name='apollo.control.SimpleLongitudinalDebug.station_error', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_error_limited', full_name='apollo.control.SimpleLongitudinalDebug.station_error_limited', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_station_error', full_name='apollo.control.SimpleLongitudinalDebug.preview_station_error', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_reference', full_name='apollo.control.SimpleLongitudinalDebug.speed_reference', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_error', full_name='apollo.control.SimpleLongitudinalDebug.speed_error', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_controller_input_limited', full_name='apollo.control.SimpleLongitudinalDebug.speed_controller_input_limited', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_speed_reference', full_name='apollo.control.SimpleLongitudinalDebug.preview_speed_reference', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_speed_error', full_name='apollo.control.SimpleLongitudinalDebug.preview_speed_error', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_acceleration_reference', full_name='apollo.control.SimpleLongitudinalDebug.preview_acceleration_reference', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_cmd_closeloop', full_name='apollo.control.SimpleLongitudinalDebug.acceleration_cmd_closeloop', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_cmd', full_name='apollo.control.SimpleLongitudinalDebug.acceleration_cmd', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_lookup', full_name='apollo.control.SimpleLongitudinalDebug.acceleration_lookup', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_lookup', full_name='apollo.control.SimpleLongitudinalDebug.speed_lookup', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration_value', full_name='apollo.control.SimpleLongitudinalDebug.calibration_value', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_cmd', full_name='apollo.control.SimpleLongitudinalDebug.throttle_cmd', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_cmd', full_name='apollo.control.SimpleLongitudinalDebug.brake_cmd', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_full_stop', full_name='apollo.control.SimpleLongitudinalDebug.is_full_stop', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slope_offset_compensation', full_name='apollo.control.SimpleLongitudinalDebug.slope_offset_compensation', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_station', full_name='apollo.control.SimpleLongitudinalDebug.current_station', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_remain', full_name='apollo.control.SimpleLongitudinalDebug.path_remain', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pid_saturation_status', full_name='apollo.control.SimpleLongitudinalDebug.pid_saturation_status', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leadlag_saturation_status', full_name='apollo.control.SimpleLongitudinalDebug.leadlag_saturation_status', index=22,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_offset', full_name='apollo.control.SimpleLongitudinalDebug.speed_offset', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_speed', full_name='apollo.control.SimpleLongitudinalDebug.current_speed', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_reference', full_name='apollo.control.SimpleLongitudinalDebug.acceleration_reference', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_acceleration', full_name='apollo.control.SimpleLongitudinalDebug.current_acceleration', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_error', full_name='apollo.control.SimpleLongitudinalDebug.acceleration_error', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk_reference', full_name='apollo.control.SimpleLongitudinalDebug.jerk_reference', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_jerk', full_name='apollo.control.SimpleLongitudinalDebug.current_jerk', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk_error', full_name='apollo.control.SimpleLongitudinalDebug.jerk_error', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_matched_point', full_name='apollo.control.SimpleLongitudinalDebug.current_matched_point', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_reference_point', full_name='apollo.control.SimpleLongitudinalDebug.current_reference_point', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_reference_point', full_name='apollo.control.SimpleLongitudinalDebug.preview_reference_point', index=33,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1252,
  serialized_end=2321,
)


_SIMPLELATERALDEBUG = _descriptor.Descriptor(
  name='SimpleLateralDebug',
  full_name='apollo.control.SimpleLateralDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lateral_error', full_name='apollo.control.SimpleLateralDebug.lateral_error', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading', full_name='apollo.control.SimpleLateralDebug.ref_heading', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.control.SimpleLateralDebug.heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error', full_name='apollo.control.SimpleLateralDebug.heading_error', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_rate', full_name='apollo.control.SimpleLateralDebug.heading_error_rate', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_error_rate', full_name='apollo.control.SimpleLateralDebug.lateral_error_rate', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature', full_name='apollo.control.SimpleLateralDebug.curvature', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle', full_name='apollo.control.SimpleLateralDebug.steer_angle', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_feedforward', full_name='apollo.control.SimpleLateralDebug.steer_angle_feedforward', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_lateral_contribution', full_name='apollo.control.SimpleLateralDebug.steer_angle_lateral_contribution', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_lateral_rate_contribution', full_name='apollo.control.SimpleLateralDebug.steer_angle_lateral_rate_contribution', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_heading_contribution', full_name='apollo.control.SimpleLateralDebug.steer_angle_heading_contribution', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_heading_rate_contribution', full_name='apollo.control.SimpleLateralDebug.steer_angle_heading_rate_contribution', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_feedback', full_name='apollo.control.SimpleLateralDebug.steer_angle_feedback', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_position', full_name='apollo.control.SimpleLateralDebug.steering_position', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_speed', full_name='apollo.control.SimpleLateralDebug.ref_speed', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_limited', full_name='apollo.control.SimpleLateralDebug.steer_angle_limited', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_acceleration', full_name='apollo.control.SimpleLateralDebug.lateral_acceleration', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_jerk', full_name='apollo.control.SimpleLateralDebug.lateral_jerk', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading_rate', full_name='apollo.control.SimpleLateralDebug.ref_heading_rate', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_rate', full_name='apollo.control.SimpleLateralDebug.heading_rate', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading_acceleration', full_name='apollo.control.SimpleLateralDebug.ref_heading_acceleration', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_acceleration', full_name='apollo.control.SimpleLateralDebug.heading_acceleration', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_acceleration', full_name='apollo.control.SimpleLateralDebug.heading_error_acceleration', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading_jerk', full_name='apollo.control.SimpleLateralDebug.ref_heading_jerk', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_jerk', full_name='apollo.control.SimpleLateralDebug.heading_jerk', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_jerk', full_name='apollo.control.SimpleLateralDebug.heading_error_jerk', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_error_feedback', full_name='apollo.control.SimpleLateralDebug.lateral_error_feedback', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_feedback', full_name='apollo.control.SimpleLateralDebug.heading_error_feedback', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_target_point', full_name='apollo.control.SimpleLateralDebug.current_target_point', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_feedback_augment', full_name='apollo.control.SimpleLateralDebug.steer_angle_feedback_augment', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_mrac_debug', full_name='apollo.control.SimpleLateralDebug.steer_mrac_debug', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_mrac_enable_status', full_name='apollo.control.SimpleLateralDebug.steer_mrac_enable_status', index=32,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2324,
  serialized_end=3367,
)


_SIMPLEMPCDEBUG = _descriptor.Descriptor(
  name='SimpleMPCDebug',
  full_name='apollo.control.SimpleMPCDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lateral_error', full_name='apollo.control.SimpleMPCDebug.lateral_error', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading', full_name='apollo.control.SimpleMPCDebug.ref_heading', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.control.SimpleMPCDebug.heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error', full_name='apollo.control.SimpleMPCDebug.heading_error', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_rate', full_name='apollo.control.SimpleMPCDebug.heading_error_rate', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_error_rate', full_name='apollo.control.SimpleMPCDebug.lateral_error_rate', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature', full_name='apollo.control.SimpleMPCDebug.curvature', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle', full_name='apollo.control.SimpleMPCDebug.steer_angle', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_feedforward', full_name='apollo.control.SimpleMPCDebug.steer_angle_feedforward', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_lateral_contribution', full_name='apollo.control.SimpleMPCDebug.steer_angle_lateral_contribution', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_lateral_rate_contribution', full_name='apollo.control.SimpleMPCDebug.steer_angle_lateral_rate_contribution', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_heading_contribution', full_name='apollo.control.SimpleMPCDebug.steer_angle_heading_contribution', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_heading_rate_contribution', full_name='apollo.control.SimpleMPCDebug.steer_angle_heading_rate_contribution', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_feedback', full_name='apollo.control.SimpleMPCDebug.steer_angle_feedback', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_position', full_name='apollo.control.SimpleMPCDebug.steering_position', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_speed', full_name='apollo.control.SimpleMPCDebug.ref_speed', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_limited', full_name='apollo.control.SimpleMPCDebug.steer_angle_limited', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_reference', full_name='apollo.control.SimpleMPCDebug.station_reference', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_error', full_name='apollo.control.SimpleMPCDebug.station_error', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_reference', full_name='apollo.control.SimpleMPCDebug.speed_reference', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_error', full_name='apollo.control.SimpleMPCDebug.speed_error', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_reference', full_name='apollo.control.SimpleMPCDebug.acceleration_reference', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_full_stop', full_name='apollo.control.SimpleMPCDebug.is_full_stop', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_feedback', full_name='apollo.control.SimpleMPCDebug.station_feedback', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_feedback', full_name='apollo.control.SimpleMPCDebug.speed_feedback', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_cmd_closeloop', full_name='apollo.control.SimpleMPCDebug.acceleration_cmd_closeloop', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_cmd', full_name='apollo.control.SimpleMPCDebug.acceleration_cmd', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_lookup', full_name='apollo.control.SimpleMPCDebug.acceleration_lookup', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_lookup', full_name='apollo.control.SimpleMPCDebug.speed_lookup', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration_value', full_name='apollo.control.SimpleMPCDebug.calibration_value', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_unconstrained_control_diff', full_name='apollo.control.SimpleMPCDebug.steer_unconstrained_control_diff', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_feedforward_compensation', full_name='apollo.control.SimpleMPCDebug.steer_angle_feedforward_compensation', index=31,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matrix_q_updated', full_name='apollo.control.SimpleMPCDebug.matrix_q_updated', index=32,
      number=33, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matrix_r_updated', full_name='apollo.control.SimpleMPCDebug.matrix_r_updated', index=33,
      number=34, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_acceleration', full_name='apollo.control.SimpleMPCDebug.lateral_acceleration', index=34,
      number=35, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_jerk', full_name='apollo.control.SimpleMPCDebug.lateral_jerk', index=35,
      number=36, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading_rate', full_name='apollo.control.SimpleMPCDebug.ref_heading_rate', index=36,
      number=37, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_rate', full_name='apollo.control.SimpleMPCDebug.heading_rate', index=37,
      number=38, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading_acceleration', full_name='apollo.control.SimpleMPCDebug.ref_heading_acceleration', index=38,
      number=39, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_acceleration', full_name='apollo.control.SimpleMPCDebug.heading_acceleration', index=39,
      number=40, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_acceleration', full_name='apollo.control.SimpleMPCDebug.heading_error_acceleration', index=40,
      number=41, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading_jerk', full_name='apollo.control.SimpleMPCDebug.ref_heading_jerk', index=41,
      number=42, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_jerk', full_name='apollo.control.SimpleMPCDebug.heading_jerk', index=42,
      number=43, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_jerk', full_name='apollo.control.SimpleMPCDebug.heading_error_jerk', index=43,
      number=44, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_feedback', full_name='apollo.control.SimpleMPCDebug.acceleration_feedback', index=44,
      number=45, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_error', full_name='apollo.control.SimpleMPCDebug.acceleration_error', index=45,
      number=46, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk_reference', full_name='apollo.control.SimpleMPCDebug.jerk_reference', index=46,
      number=47, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk_feedback', full_name='apollo.control.SimpleMPCDebug.jerk_feedback', index=47,
      number=48, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk_error', full_name='apollo.control.SimpleMPCDebug.jerk_error', index=48,
      number=49, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3370,
  serialized_end=4764,
)


_MRACDEBUG = _descriptor.Descriptor(
  name='MracDebug',
  full_name='apollo.control.MracDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mrac_model_order', full_name='apollo.control.MracDebug.mrac_model_order', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mrac_reference_state', full_name='apollo.control.MracDebug.mrac_reference_state', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mrac_state_error', full_name='apollo.control.MracDebug.mrac_state_error', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mrac_adaptive_gain', full_name='apollo.control.MracDebug.mrac_adaptive_gain', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mrac_reference_saturation_status', full_name='apollo.control.MracDebug.mrac_reference_saturation_status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mrac_control_saturation_status', full_name='apollo.control.MracDebug.mrac_control_saturation_status', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4767,
  serialized_end=5004,
)


_MRACADAPTIVEGAIN = _descriptor.Descriptor(
  name='MracAdaptiveGain',
  full_name='apollo.control.MracAdaptiveGain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_adaptive_gain', full_name='apollo.control.MracAdaptiveGain.state_adaptive_gain', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_adaptive_gain', full_name='apollo.control.MracAdaptiveGain.input_adaptive_gain', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonlinear_adaptive_gain', full_name='apollo.control.MracAdaptiveGain.nonlinear_adaptive_gain', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5006,
  serialized_end=5115,
)


_DEBUG = _descriptor.Descriptor(
  name='Debug',
  full_name='apollo.control.Debug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='simple_lon_debug', full_name='apollo.control.Debug.simple_lon_debug', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simple_lat_debug', full_name='apollo.control.Debug.simple_lat_debug', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_debug', full_name='apollo.control.Debug.input_debug', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simple_mpc_debug', full_name='apollo.control.Debug.simple_mpc_debug', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5118,
  serialized_end=5361,
)

_CONTROLCOMMAND.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_CONTROLCOMMAND.fields_by_name['driving_mode'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_DRIVINGMODE
_CONTROLCOMMAND.fields_by_name['gear_location'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_GEARPOSITION
_CONTROLCOMMAND.fields_by_name['debug'].message_type = _DEBUG
_CONTROLCOMMAND.fields_by_name['signal'].message_type = modules_dot_common_dot_proto_dot_vehicle__signal__pb2._VEHICLESIGNAL
_CONTROLCOMMAND.fields_by_name['latency_stats'].message_type = _LATENCYSTATS
_CONTROLCOMMAND.fields_by_name['pad_msg'].message_type = modules_dot_control_dot_proto_dot_pad__msg__pb2._PADMESSAGE
_CONTROLCOMMAND.fields_by_name['engage_advice'].message_type = modules_dot_common_dot_proto_dot_drive__state__pb2._ENGAGEADVICE
_CONTROLCOMMAND.fields_by_name['turnsignal'].enum_type = _TURNSIGNAL
_SIMPLELONGITUDINALDEBUG.fields_by_name['current_matched_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_SIMPLELONGITUDINALDEBUG.fields_by_name['current_reference_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_SIMPLELONGITUDINALDEBUG.fields_by_name['preview_reference_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_SIMPLELATERALDEBUG.fields_by_name['current_target_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_SIMPLELATERALDEBUG.fields_by_name['steer_mrac_debug'].message_type = _MRACDEBUG
_MRACDEBUG.fields_by_name['mrac_adaptive_gain'].message_type = _MRACADAPTIVEGAIN
_DEBUG.fields_by_name['simple_lon_debug'].message_type = _SIMPLELONGITUDINALDEBUG
_DEBUG.fields_by_name['simple_lat_debug'].message_type = _SIMPLELATERALDEBUG
_DEBUG.fields_by_name['input_debug'].message_type = modules_dot_control_dot_proto_dot_input__debug__pb2._INPUTDEBUG
_DEBUG.fields_by_name['simple_mpc_debug'].message_type = _SIMPLEMPCDEBUG
DESCRIPTOR.message_types_by_name['LatencyStats'] = _LATENCYSTATS
DESCRIPTOR.message_types_by_name['ControlCommand'] = _CONTROLCOMMAND
DESCRIPTOR.message_types_by_name['SimpleLongitudinalDebug'] = _SIMPLELONGITUDINALDEBUG
DESCRIPTOR.message_types_by_name['SimpleLateralDebug'] = _SIMPLELATERALDEBUG
DESCRIPTOR.message_types_by_name['SimpleMPCDebug'] = _SIMPLEMPCDEBUG
DESCRIPTOR.message_types_by_name['MracDebug'] = _MRACDEBUG
DESCRIPTOR.message_types_by_name['MracAdaptiveGain'] = _MRACADAPTIVEGAIN
DESCRIPTOR.message_types_by_name['Debug'] = _DEBUG
DESCRIPTOR.enum_types_by_name['TurnSignal'] = _TURNSIGNAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LatencyStats = _reflection.GeneratedProtocolMessageType('LatencyStats', (_message.Message,), {
  'DESCRIPTOR' : _LATENCYSTATS,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.LatencyStats)
  })
_sym_db.RegisterMessage(LatencyStats)

ControlCommand = _reflection.GeneratedProtocolMessageType('ControlCommand', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLCOMMAND,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.ControlCommand)
  })
_sym_db.RegisterMessage(ControlCommand)

SimpleLongitudinalDebug = _reflection.GeneratedProtocolMessageType('SimpleLongitudinalDebug', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLELONGITUDINALDEBUG,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.SimpleLongitudinalDebug)
  })
_sym_db.RegisterMessage(SimpleLongitudinalDebug)

SimpleLateralDebug = _reflection.GeneratedProtocolMessageType('SimpleLateralDebug', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLELATERALDEBUG,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.SimpleLateralDebug)
  })
_sym_db.RegisterMessage(SimpleLateralDebug)

SimpleMPCDebug = _reflection.GeneratedProtocolMessageType('SimpleMPCDebug', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLEMPCDEBUG,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.SimpleMPCDebug)
  })
_sym_db.RegisterMessage(SimpleMPCDebug)

MracDebug = _reflection.GeneratedProtocolMessageType('MracDebug', (_message.Message,), {
  'DESCRIPTOR' : _MRACDEBUG,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.MracDebug)
  })
_sym_db.RegisterMessage(MracDebug)

MracAdaptiveGain = _reflection.GeneratedProtocolMessageType('MracAdaptiveGain', (_message.Message,), {
  'DESCRIPTOR' : _MRACADAPTIVEGAIN,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.MracAdaptiveGain)
  })
_sym_db.RegisterMessage(MracAdaptiveGain)

Debug = _reflection.GeneratedProtocolMessageType('Debug', (_message.Message,), {
  'DESCRIPTOR' : _DEBUG,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.Debug)
  })
_sym_db.RegisterMessage(Debug)


_CONTROLCOMMAND.fields_by_name['reset_model']._options = None
_CONTROLCOMMAND.fields_by_name['driving_mode']._options = None
_CONTROLCOMMAND.fields_by_name['left_turn']._options = None
_CONTROLCOMMAND.fields_by_name['right_turn']._options = None
_CONTROLCOMMAND.fields_by_name['high_beam']._options = None
_CONTROLCOMMAND.fields_by_name['low_beam']._options = None
_CONTROLCOMMAND.fields_by_name['horn']._options = None
_CONTROLCOMMAND.fields_by_name['turnsignal']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/proto/map_geometry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/proto/map_geometry.proto',
  package='apollo.hdmap',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/map/proto/map_geometry.proto\x12\x0c\x61pollo.hdmap\x1a#modules/common/proto/geometry.proto\"1\n\x07Polygon\x12&\n\x05point\x18\x01 \x03(\x0b\x32\x17.apollo.common.PointENU\"5\n\x0bLineSegment\x12&\n\x05point\x18\x01 \x03(\x0b\x32\x17.apollo.common.PointENU\"\xac\x01\n\x0c\x43urveSegment\x12\x31\n\x0cline_segment\x18\x01 \x01(\x0b\x32\x19.apollo.hdmap.LineSegmentH\x00\x12\t\n\x01s\x18\x06 \x01(\x01\x12/\n\x0estart_position\x18\x07 \x01(\x0b\x32\x17.apollo.common.PointENU\x12\x0f\n\x07heading\x18\x08 \x01(\x01\x12\x0e\n\x06length\x18\t \x01(\x01\x42\x0c\n\ncurve_type\"4\n\x05\x43urve\x12+\n\x07segment\x18\x01 \x03(\x0b\x32\x1a.apollo.hdmap.CurveSegment'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])




_POLYGON = _descriptor.Descriptor(
  name='Polygon',
  full_name='apollo.hdmap.Polygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='apollo.hdmap.Polygon.point', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=140,
)


_LINESEGMENT = _descriptor.Descriptor(
  name='LineSegment',
  full_name='apollo.hdmap.LineSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='apollo.hdmap.LineSegment.point', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=195,
)


_CURVESEGMENT = _descriptor.Descriptor(
  name='CurveSegment',
  full_name='apollo.hdmap.CurveSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='line_segment', full_name='apollo.hdmap.CurveSegment.line_segment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.hdmap.CurveSegment.s', index=1,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_position', full_name='apollo.hdmap.CurveSegment.start_position', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.hdmap.CurveSegment.heading', index=3,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.hdmap.CurveSegment.length', index=4,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='curve_type', full_name='apollo.hdmap.CurveSegment.curve_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=198,
  serialized_end=370,
)


_CURVE = _descriptor.Descriptor(
  name='Curve',
  full_name='apollo.hdmap.Curve',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segment', full_name='apollo.hdmap.Curve.segment', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=372,
  serialized_end=424,
)

_POLYGON.fields_by_name['point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_LINESEGMENT.fields_by_name['point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_CURVESEGMENT.fields_by_name['line_segment'].message_type = _LINESEGMENT
_CURVESEGMENT.fields_by_name['start_position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_CURVESEGMENT.oneofs_by_name['curve_type'].fields.append(
  _CURVESEGMENT.fields_by_name['line_segment'])
_CURVESEGMENT.fields_by_name['line_segment'].containing_oneof = _CURVESEGMENT.oneofs_by_name['curve_type']
_CURVE.fields_by_name['segment'].message_type = _CURVESEGMENT
DESCRIPTOR.message_types_by_name['Polygon'] = _POLYGON
DESCRIPTOR.message_types_by_name['LineSegment'] = _LINESEGMENT
DESCRIPTOR.message_types_by_name['CurveSegment'] = _CURVESEGMENT
DESCRIPTOR.message_types_by_name['Curve'] = _CURVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Polygon = _reflection.GeneratedProtocolMessageType('Polygon', (_message.Message,), {
  'DESCRIPTOR' : _POLYGON,
  '__module__' : 'modules.map.proto.map_geometry_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.Polygon)
  })
_sym_db.RegisterMessage(Polygon)

LineSegment = _reflection.GeneratedProtocolMessageType('LineSegment', (_message.Message,), {
  'DESCRIPTOR' : _LINESEGMENT,
  '__module__' : 'modules.map.proto.map_geometry_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.LineSegment)
  })
_sym_db.RegisterMessage(LineSegment)

CurveSegment = _reflection.GeneratedProtocolMessageType('CurveSegment', (_message.Message,), {
  'DESCRIPTOR' : _CURVESEGMENT,
  '__module__' : 'modules.map.proto.map_geometry_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.CurveSegment)
  })
_sym_db.RegisterMessage(CurveSegment)

Curve = _reflection.GeneratedProtocolMessageType('Curve', (_message.Message,), {
  'DESCRIPTOR' : _CURVE,
  '__module__' : 'modules.map.proto.map_geometry_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.Curve)
  })
_sym_db.RegisterMessage(Curve)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/component_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cyber.proto import qos_profile_pb2 as cyber_dot_proto_dot_qos__profile__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/component_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n cyber/proto/component_conf.proto\x12\x12\x61pollo.cyber.proto\x1a\x1d\x63yber/proto/qos_profile.proto\"s\n\x0cReaderOption\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\x12\x33\n\x0bqos_profile\x18\x02 \x01(\x0b\x32\x1e.apollo.cyber.proto.QosProfile\x12\x1d\n\x12pending_queue_size\x18\x03 \x01(\r:\x01\x31\"\x84\x01\n\x0f\x43omponentConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10\x63onfig_file_path\x18\x02 \x01(\t\x12\x16\n\x0e\x66lag_file_path\x18\x03 \x01(\t\x12\x31\n\x07readers\x18\x04 \x03(\x0b\x32 .apollo.cyber.proto.ReaderOption\"h\n\x14TimerComponentConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10\x63onfig_file_path\x18\x02 \x01(\t\x12\x16\n\x0e\x66lag_file_path\x18\x03 \x01(\t\x12\x10\n\x08interval\x18\x04 \x01(\r'
  ,
  dependencies=[cyber_dot_proto_dot_qos__profile__pb2.DESCRIPTOR,])




_READEROPTION = _descriptor.Descriptor(
  name='ReaderOption',
  full_name='apollo.cyber.proto.ReaderOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='apollo.cyber.proto.ReaderOption.channel', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qos_profile', full_name='apollo.cyber.proto.ReaderOption.qos_profile', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_queue_size', full_name='apollo.cyber.proto.ReaderOption.pending_queue_size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=202,
)


_COMPONENTCONFIG = _descriptor.Descriptor(
  name='ComponentConfig',
  full_name='apollo.cyber.proto.ComponentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.ComponentConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_file_path', full_name='apollo.cyber.proto.ComponentConfig.config_file_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flag_file_path', full_name='apollo.cyber.proto.ComponentConfig.flag_file_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readers', full_name='apollo.cyber.proto.ComponentConfig.readers', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=337,
)


_TIMERCOMPONENTCONFIG = _descriptor.Descriptor(
  name='TimerComponentConfig',
  full_name='apollo.cyber.proto.TimerComponentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.TimerComponentConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_file_path', full_name='apollo.cyber.proto.TimerComponentConfig.config_file_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flag_file_path', full_name='apollo.cyber.proto.TimerComponentConfig.flag_file_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='apollo.cyber.proto.TimerComponentConfig.interval', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=443,
)

_READEROPTION.fields_by_name['qos_profile'].message_type = cyber_dot_proto_dot_qos__profile__pb2._QOSPROFILE
_COMPONENTCONFIG.fields_by_name['readers'].message_type = _READEROPTION
DESCRIPTOR.message_types_by_name['ReaderOption'] = _READEROPTION
DESCRIPTOR.message_types_by_name['ComponentConfig'] = _COMPONENTCONFIG
DESCRIPTOR.message_types_by_name['TimerComponentConfig'] = _TIMERCOMPONENTCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReaderOption = _reflection.GeneratedProtocolMessageType('ReaderOption', (_message.Message,), {
  'DESCRIPTOR' : _READEROPTION,
  '__module__' : 'cyber.proto.component_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ReaderOption)
  })
_sym_db.RegisterMessage(ReaderOption)

ComponentConfig = _reflection.GeneratedProtocolMessageType('ComponentConfig', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTCONFIG,
  '__module__' : 'cyber.proto.component_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ComponentConfig)
  })
_sym_db.RegisterMessage(ComponentConfig)

TimerComponentConfig = _reflection.GeneratedProtocolMessageType('TimerComponentConfig', (_message.Message,), {
  'DESCRIPTOR' : _TIMERCOMPONENTCONFIG,
  '__module__' : 'cyber.proto.component_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.TimerComponentConfig)
  })
_sym_db.RegisterMessage(TimerComponentConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/cyber_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cyber.proto import scheduler_conf_pb2 as cyber_dot_proto_dot_scheduler__conf__pb2
from cyber.proto import transport_conf_pb2 as cyber_dot_proto_dot_transport__conf__pb2
from cyber.proto import run_mode_conf_pb2 as cyber_dot_proto_dot_run__mode__conf__pb2
from cyber.proto import perf_conf_pb2 as cyber_dot_proto_dot_perf__conf__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/cyber_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x63yber/proto/cyber_conf.proto\x12\x12\x61pollo.cyber.proto\x1a cyber/proto/scheduler_conf.proto\x1a cyber/proto/transport_conf.proto\x1a\x1f\x63yber/proto/run_mode_conf.proto\x1a\x1b\x63yber/proto/perf_conf.proto\"\xec\x01\n\x0b\x43yberConfig\x12\x39\n\x0escheduler_conf\x18\x01 \x01(\x0b\x32!.apollo.cyber.proto.SchedulerConf\x12\x39\n\x0etransport_conf\x18\x02 \x01(\x0b\x32!.apollo.cyber.proto.TransportConf\x12\x36\n\rrun_mode_conf\x18\x03 \x01(\x0b\x32\x1f.apollo.cyber.proto.RunModeConf\x12/\n\tperf_conf\x18\x04 \x01(\x0b\x32\x1c.apollo.cyber.proto.PerfConf'
  ,
  dependencies=[cyber_dot_proto_dot_scheduler__conf__pb2.DESCRIPTOR,cyber_dot_proto_dot_transport__conf__pb2.DESCRIPTOR,cyber_dot_proto_dot_run__mode__conf__pb2.DESCRIPTOR,cyber_dot_proto_dot_perf__conf__pb2.DESCRIPTOR,])




_CYBERCONFIG = _descriptor.Descriptor(
  name='CyberConfig',
  full_name='apollo.cyber.proto.CyberConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheduler_conf', full_name='apollo.cyber.proto.CyberConfig.scheduler_conf', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_conf', full_name='apollo.cyber.proto.CyberConfig.transport_conf', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_mode_conf', full_name='apollo.cyber.proto.CyberConfig.run_mode_conf', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perf_conf', full_name='apollo.cyber.proto.CyberConfig.perf_conf', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=419,
)

_CYBERCONFIG.fields_by_name['scheduler_conf'].message_type = cyber_dot_proto_dot_scheduler__conf__pb2._SCHEDULERCONF
_CYBERCONFIG.fields_by_name['transport_conf'].message_type = cyber_dot_proto_dot_transport__conf__pb2._TRANSPORTCONF
_CYBERCONFIG.fields_by_name['run_mode_conf'].message_type = cyber_dot_proto_dot_run__mode__conf__pb2._RUNMODECONF
_CYBERCONFIG.fields_by_name['perf_conf'].message_type = cyber_dot_proto_dot_perf__conf__pb2._PERFCONF
DESCRIPTOR.message_types_by_name['CyberConfig'] = _CYBERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CyberConfig = _reflection.GeneratedProtocolMessageType('CyberConfig', (_message.Message,), {
  'DESCRIPTOR' : _CYBERCONFIG,
  '__module__' : 'cyber.proto.cyber_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.CyberConfig)
  })
_sym_db.RegisterMessage(CyberConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/microphone/proto/audio.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.drivers.microphone.proto import microphone_config_pb2 as modules_dot_drivers_dot_microphone_dot_proto_dot_microphone__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/microphone/proto/audio.proto',
  package='apollo.drivers.microphone.config',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,modules/drivers/microphone/proto/audio.proto\x12 apollo.drivers.microphone.config\x1a!modules/common/proto/header.proto\x1a\x38modules/drivers/microphone/proto/microphone_config.proto\"`\n\x0b\x43hannelData\x12\x43\n\x0c\x63hannel_type\x18\x01 \x01(\x0e\x32-.apollo.drivers.microphone.config.ChannelType\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\xc6\x01\n\tAudioData\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12M\n\x11microphone_config\x18\x02 \x01(\x0b\x32\x32.apollo.drivers.microphone.config.MicrophoneConfig\x12\x43\n\x0c\x63hannel_data\x18\x03 \x03(\x0b\x32-.apollo.drivers.microphone.config.ChannelData'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_drivers_dot_microphone_dot_proto_dot_microphone__config__pb2.DESCRIPTOR,])




_CHANNELDATA = _descriptor.Descriptor(
  name='ChannelData',
  full_name='apollo.drivers.microphone.config.ChannelData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_type', full_name='apollo.drivers.microphone.config.ChannelData.channel_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='apollo.drivers.microphone.config.ChannelData.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=271,
)


_AUDIODATA = _descriptor.Descriptor(
  name='AudioData',
  full_name='apollo.drivers.microphone.config.AudioData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.microphone.config.AudioData.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='microphone_config', full_name='apollo.drivers.microphone.config.AudioData.microphone_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_data', full_name='apollo.drivers.microphone.config.AudioData.channel_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=274,
  serialized_end=472,
)

_CHANNELDATA.fields_by_name['channel_type'].enum_type = modules_dot_drivers_dot_microphone_dot_proto_dot_microphone__config__pb2._CHANNELTYPE
_AUDIODATA.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_AUDIODATA.fields_by_name['microphone_config'].message_type = modules_dot_drivers_dot_microphone_dot_proto_dot_microphone__config__pb2._MICROPHONECONFIG
_AUDIODATA.fields_by_name['channel_data'].message_type = _CHANNELDATA
DESCRIPTOR.message_types_by_name['ChannelData'] = _CHANNELDATA
DESCRIPTOR.message_types_by_name['AudioData'] = _AUDIODATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChannelData = _reflection.GeneratedProtocolMessageType('ChannelData', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELDATA,
  '__module__' : 'modules.drivers.microphone.proto.audio_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.microphone.config.ChannelData)
  })
_sym_db.RegisterMessage(ChannelData)

AudioData = _reflection.GeneratedProtocolMessageType('AudioData', (_message.Message,), {
  'DESCRIPTOR' : _AUDIODATA,
  '__module__' : 'modules.drivers.microphone.proto.audio_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.microphone.config.AudioData)
  })
_sym_db.RegisterMessage(AudioData)


# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python

# Copyright 2022 daohu527 <daohu527@gmail.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

###############################################################################

# Copyright 2019 The Apollo Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import cv2
import numpy as np
import os

from functools import reduce

from record_msg import pypcd


def to_csv(msg):
  """Flatten the properties of the object, output as an array

  Args:
      msg (_type_): _description_

  Returns:
      _type_: _description_
  """
  if type(msg) in (int, float, bool, str, bytes):
    return [msg]
  elif msg and type(msg) in (tuple, list):
    return reduce(lambda x, y: x + y, map(lambda m: to_csv(m), msg))
  elif hasattr(msg, 'DESCRIPTOR'):
    pb_attrs = msg.DESCRIPTOR.fields_by_name.keys()
    flat_attrs = list(map(lambda attr: getattr(msg, attr), pb_attrs))
    return to_csv(flat_attrs)
  else:
    return []


class Parser(object):
  def __init__(self, output_path, instance_saving, suffix):
    self._output_path = output_path
    self._instance_saving = instance_saving
    self._suffix = suffix
    self._msg_count = 0


class ImageParser(Parser):
  def __init__(self, output_path, instance_saving=True, suffix='.jpg') -> None:
    super(ImageParser, self).__init__(output_path, instance_saving, suffix)

  def _valid(self, image):
    # Save image according to cyber format, defined in sensor camera proto.
    # height = 4, image height, that is, number of rows.
    # width = 5,  image width, that is, number of columns.
    # encoding = 6, as string, type is 'rgb8', 'bgr8' or 'gray'.
    # step = 7, full row length in bytes.
    # data = 8, actual matrix data in bytes, size is (step * rows).
    # type = CV_8UC1 if image step is equal to width as gray, CV_8UC3
    # if step * 3 is equal to width.
    if image.encoding == 'rgb8' or image.encoding == 'bgr8':
      if image.step != image.width * 3:
        print('Image.step %d does not equal to Image.width %d * 3 for color image.'
              % (image.step, image.width))
        return False
      else:
        return True
    elif image.encoding == 'gray' or image.encoding == 'y':
      if image.step != image.width:
        print('Image.step %d does not equal to Image.width %d or gray image.'
              % (image.step, image.width))
        return False
      else:
        return True
    else:
      print('Unsupported image encoding type: %s.' % image.encoding)
      return False

  def parse(self, image, file_name=None):
    if not self._valid(image):
      return None

    channel_num = image.step // image.width
    self._parsed_data = np.fromstring(image.data, dtype=np.uint8).reshape(
        (image.height, image.width, channel_num))
    self._encoding = image.encoding

    if self._instance_saving:
      if file_name is None:
        file_name = "%05d" % self._msg_count + self._suffix
      else:
        file_name = str(file_name) + self._suffix
      output_file = os.path.join(self._output_path, file_name)
      self.save_image_mat_to_file(image_file=output_file)
      self._msg_count += 1
    return self._parsed_data

  def save_image_mat_to_file(self, image_file):
    # Save image in BGR oder
    image_mat = self._parsed_data
    if self._encoding == 'rgb8':
      cv2.imwrite(image_file, cv2.cvtColor(image_mat, cv2.COLOR_RGB2BGR))
    else:
      cv2.imwrite(image_file, image_mat)


class PointCloudParser(Parser):
  def __init__(self, output_path, instance_saving=True, suffix='.pcd'):
    super(PointCloudParser, self).__init__(output_path, instance_saving, suffix)

  def convert_xyzit_pb_to_array(self, xyz_i_t, data_type):
    arr = np.zeros(len(xyz_i_t), dtype=data_type)
    for i, point in enumerate(xyz_i_t):
      # change timestamp to timestamp_sec
      arr[i] = (point.x, point.y, point.z,
                point.intensity, point.timestamp/1e9)
    return arr

  def make_xyzit_point_cloud(self, xyz_i_t):
    """
    Make a pointcloud object from PointXYZIT message, as Pointcloud.proto.
    message PointXYZIT {
      optional float x = 1 [default = nan];
      optional float y = 2 [default = nan];
      optional float z = 3 [default = nan];
      optional uint32 intensity = 4 [default = 0];
      optional uint64 timestamp = 5 [default = 0];
    }
    """

    md = {'version': .7,
          'fields': ['x', 'y', 'z', 'intensity', 'timestamp'],
          'count': [1, 1, 1, 1, 1],
          'width': len(xyz_i_t),
          'height': 1,
          'viewpoint': [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0],
          'points': len(xyz_i_t),
          'type': ['F', 'F', 'F', 'U', 'F'],
          'size': [4, 4, 4, 4, 8],
          'data': 'binary_compressed'}

    typenames = []
    for t, s in zip(md['type'], md['size']):
      np_type = pypcd.pcd_type_to_numpy_type[(t, s)]
      typenames.append(np_type)

    np_dtype = np.dtype(list(zip(md['fields'], typenames)))
    pc_data = self.convert_xyzit_pb_to_array(xyz_i_t, data_type=np_dtype)
    pc = pypcd.PointCloud(md, pc_data)
    return pc

  def save_pointcloud_meta_to_file(self, pc_meta, pcd_file, mode):
    if mode == 'ascii':
      pypcd.save_point_cloud(pc_meta, pcd_file)
    elif mode == 'binary':
      pypcd.save_point_cloud_bin(pc_meta, pcd_file)
    elif mode == 'binary_compressed':
      pypcd.save_point_cloud_bin_compressed(pc_meta, pcd_file)
    else:
      print("Unknown point cloud format!")

  def parse(self, pointcloud, file_name=None, mode='ascii'):
    """
    Transform protobuf PointXYZIT to standard PCL bin_compressed_file(*.pcd).
    """
    self._parsed_data = self.make_xyzit_point_cloud(pointcloud.point)

    if self._instance_saving:
      if file_name is None:
        file_name = "%05d" % self._msg_count + self._suffix
      else:
        file_name = str(file_name) + self._suffix
      output_file = os.path.join(self._output_path, file_name)
      self.save_pointcloud_meta_to_file(pc_meta=self._parsed_data, \
          pcd_file=output_file, mode=mode)
      self._msg_count += 1
    return self._parsed_data
